@@ -23,7 +23,7 @@
 #'
 #' @examples
 #' data(acme)
-#' acme$fieldsAll
+#' acme$attributesAll
 #' as.data.frame(acme, row.names = NULL, optional = FALSE, "cost", "p")
 #'
 #' ToDataFrameTree(acme, "cost", "p")
@@ -370,7 +370,7 @@ FromDataFrameTable <- function(table,
 #' \itemize{
 #'  \item{It must contain as many rows as there are nodes (excluding the root, there is no row for the root)}
 #'  \item{Its first and second columns contain the network relationships. This can be either climbing (from parent to children) or descending (from child to parent)}
-#'  \item{Its subsequent columns contain the attributes to be set as fields on the nodes}
+#'  \item{Its subsequent columns contain the attributes to be set on the nodes}
 #'  \item{It must contain a single root}
 #'  \item{There are no cycles in the network}
 #' }
@@ -409,6 +409,7 @@ FromDataFrameNetwork <- function(network, check = c("check", "no-warn", "no-chec
           vlu <- network[idx, j]
           if (!is.na(vlu)) {
             nm <- names(network)[j]
+            nm <- CheckNameReservedWord(nm, check)
             if (!nm %in% NODE_RESERVED_NAMES_CONST) child[[nm]] <- network[idx, j]
           }
         }
