@@ -1,4 +1,4 @@
-## ----echo=F--------------------------------------------------------------
+## ----echo=F-------------------------------------------------------------------
 ### get knitr just the way we like it
 
 knitr::opts_chunk$set(
@@ -10,7 +10,7 @@ knitr::opts_chunk$set(
 )
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(data.tree)
 
 acme <- Node$new("Acme Inc.")
@@ -27,23 +27,23 @@ acme <- Node$new("Acme Inc.")
 
 print(acme)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(treemap)
 data(GNI2014)
 head(GNI2014)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 GNI2014$pathString <- paste("world", 
                             GNI2014$continent, 
                             GNI2014$country, 
                             sep = "/")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 population <- as.Node(GNI2014)
 print(population, "iso3", "population", "GNI", limit = 20)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(yaml)
 yaml <- "
 name: OS Students 2014/15
@@ -70,61 +70,61 @@ osList <- yaml.load(yaml)
 osNode <- as.Node(osList)
 print(osNode, "users")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 print(population, limit = 15)
 population$isRoot
 population$height
 population$count
 population$totalCount
-population$fields
-population$fieldsAll
+population$attributes
+population$attributesAll
 population$averageBranchingFactor
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 sum(population$Get("population", filterFun = isLeaf))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 Prune(population, pruneFun = function(x) !x$isLeaf || x$population > 1000000)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 sum(population$Get("population", filterFun = isLeaf), na.rm = TRUE)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 popClone <- Clone(acme)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 as.data.frame(acme)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ToDataFrameNetwork(acme)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$IT$Outsource
 acme$Research$`New Labs`
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 acme$children[[1]]$children[[2]]$name
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Climb(position = 1, name = "New Software")$path
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tree <- CreateRegularTree(5, 5)
 tree$Climb(position = c(2, 3, 4))$path
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tree$Climb(position = c(2, 3), name = c("1.2.3.4", "1.2.3.4.5"))$path
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Accounting$`New Software`$cost <- 1000000
 acme$Accounting$`New Accounting Standards`$cost <- 500000
 acme$Research$`New Product Line`$cost <- 2000000
@@ -143,46 +143,46 @@ acme$IT$`Switch to R`$p <- 1
 print(acme, "cost", "p")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 NODE_RESERVED_NAMES_CONST
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 birds <- Node$new("Aves", vulgo = "Bird")
 birds$AddChild("Neognathae", vulgo = "New Jaws", species = 10000)
 birds$AddChild("Palaeognathae", vulgo = "Old Jaws", species = 60)
 print(birds, "vulgo", "species")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 birds$species <- function(self) sum(sapply(self$children, function(x) x$species))
 print(birds, "species")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 birds$Palaeognathae$species <- 61
 print(birds, "species")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 print(acme, "cost", "p")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 SetFormat(acme, "p", formatFun = FormatPercent)
 SetFormat(acme, "cost", formatFun = function(x) FormatFixedDecimal(x, digits = 2))
 print(acme, "cost", "p")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 data.frame(cost = acme$Get("cost", format = function(x) FormatFixedDecimal(x, 2)),
            p = acme$Get("p", format = FormatPercent))
            
 
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  plot(acme)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  SetGraphStyle(acme, rankdir = "TB")
 #  SetEdgeStyle(acme, arrowhead = "vee", color = "grey35", penwidth = 2)
 #  SetNodeStyle(acme, style = "filled,rounded", shape = "box", fillcolor = "GreenYellow",
@@ -190,31 +190,31 @@ data.frame(cost = acme$Get("cost", format = function(x) FormatFixedDecimal(x, 2)
 #  SetNodeStyle(acme$IT, fillcolor = "LightBlue", penwidth = "5px")
 #  plot(acme)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  SetNodeStyle(acme$Accounting, inherit = FALSE, fillcolor = "Thistle",
 #               fontcolor = "Firebrick", tooltip = "This is the accounting department")
 #  plot(acme)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  Do(acme$leaves, function(node) SetNodeStyle(node, shape = "egg"))
 #  plot(acme)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 plot(as.dendrogram(CreateRandomTree(nodes = 20)), center = TRUE)
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 library(igraph, quietly = TRUE, warn.conflicts = FALSE, verbose = FALSE)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(igraph)
 plot(as.igraph(acme, directed = TRUE, direction = "climb"))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(networkD3)
 acmeNetwork <- ToDataFrameNetwork(acme, "name")
 simpleNetwork(acmeNetwork[-3], fontSize = 12)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 fileName <- system.file("extdata", "useR15.csv", package="data.tree")
 useRdf <- read.csv(fileName, stringsAsFactors = FALSE)
 #define the hierarchy (Session/Room/Speaker)
@@ -227,66 +227,66 @@ useRtreeList <- ToListExplicit(useRtree, unname = TRUE)
 radialNetwork( useRtreeList)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acmedf <- as.data.frame(acme)
 as.data.frame(acme$IT)
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  ToDataFrameTree(acme)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ToDataFrameTree(acme, "level", "cost")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ToDataFrameTable(acme, "pathString", "cost")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ToDataFrameNetwork(acme, "cost")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ToDataFrameTypeCol(acme, 'cost')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$IT$Outsource$AddChild("India")
 acme$IT$Outsource$AddChild("Poland")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Set(type = c('company', 'department', 'project', 'project', 'department', 'project', 'project', 'department', 'program', 'project', 'project', 'project', 'project'))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 print(acme, 'type')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 ToDataFrameTypeCol(acme, type = 'type', prefix = NULL)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 data(acme)
 str(as.list(acme$IT))
 str(ToListExplicit(acme$IT, unname = FALSE, nameName = "id", childrenName = "dependencies"))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 print(acme, "level")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Get('level', traversal = "post-order")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 data.frame(level = agile$Get('level', traversal = "ancestor"))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Get('name', pruneFun = function(x) x$position <= 2)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Get('name', filterFun = isLeaf)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Get('name')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 ExpectedCost <- function(node, adjustmentFactor = 1) {
   return ( node$cost * node$p * adjustmentFactor)
@@ -295,7 +295,7 @@ ExpectedCost <- function(node, adjustmentFactor = 1) {
 acme$Get(ExpectedCost, adjustmentFactor = 0.9, filterFun = isLeaf)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 Cost <- function(node) {
   result <- node$cost
   if(length(result) == 0) result <- sum(sapply(node$children, Cost))
@@ -304,18 +304,18 @@ Cost <- function(node) {
 
 print(acme, "p", cost = Cost)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 acme$Do(function(node) node$cost <- Cost(node), filterFun = isNotLeaf)
 print(acme, "p", "cost")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Set(id = 1:acme$totalCount)
 
 print(acme, "id")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 secretaries <- c(3, 2, 8)
 employees <- c(52, 43, 51)
 acme$Set(secretaries, 
@@ -325,16 +325,16 @@ print(acme, "emps", "secretaries", "id")
 
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Set(avgExpectedCost = NULL)
 
-## ------------------------------------------------------------------------
-acme$fieldsAll
+## -----------------------------------------------------------------------------
+acme$attributesAll
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Do(function(node) node$RemoveAttribute("avgExpectedCost"))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Set(cost = c(function(self) sum(sapply(self$children, 
                                             function(child) GetAttribute(child, "cost")))), 
          filterFun = isNotLeaf)
@@ -342,7 +342,7 @@ print(acme, "cost")
 acme$IT$AddChild("Paperless", cost = 240000)
 print(acme, "cost")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 traversal <- Traverse(acme, traversal = "post-order", filterFun = function(x) x$level == 2)
 Set(traversal, floor = c(1, 2, 3))
 Do(traversal, function(x) {
@@ -355,27 +355,27 @@ Do(traversal, function(x) {
 Get(traversal, "extension")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 Aggregate(node = acme, attribute = "cost", aggFun = sum)
 
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  acme$Get(Aggregate, "cost", sum)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Do(function(node) node$cost <- Aggregate(node, attribute = "cost", aggFun = sum), traversal = "post-order")
 print(acme, "cost")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 Cumulate(acme$IT$`Go agile`, "cost", sum)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 Cumulate(acme$IT$`Go agile`, "cost", min)
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 acme$Do(function(node) node$cumCost <- Cumulate(node, 
                                                 attribute = "cost", 
@@ -383,64 +383,64 @@ acme$Do(function(node) node$cumCost <- Cumulate(node,
 print(acme, "cost", "cumCost")
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acmeClone <- Clone(acme)
 acmeClone$name <- "New Acme"
 # acmeClone does not point to the same reference object anymore:
 acme$name == acmeClone$name
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 Sort(acme, "name")
 acme
 Sort(acme, Aggregate, "cost", sum, decreasing = TRUE, recursive = TRUE)
 print(acme, "cost", aggCost = acme$Get(Aggregate, "cost", sum))
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 acme$Do(function(x) x$cost <- Aggregate(x, "cost", sum))
 Prune(acme, function(x) x$cost > 700000)
 print(acme, "cost")
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  system.time(tree <- CreateRegularTree(6, 6))
 
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 c(user = 2.499, system = 0.009, elapsed = 2.506)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  system.time(tree <- Clone(tree))
 
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 c(user = 3.704, system = 0.023, elapsed = 3.726)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  system.time(traversal <- Traverse(tree))
 
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 c(user = 0.096, system = 0.000, elapsed = 0.097)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  system.time(Set(traversal, id = 1:tree$totalCount))
 
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 c(user = 0.205, system = 0.000, elapsed = 0.204)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  system.time(ids <- Get(traversal, "id"))
 
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 c(user = 0.569, system = 0.000, elapsed = 0.569)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  leaves <- Traverse(tree, filterFun = isLeaf)
 #  Set(leaves, leafId = 1:length(leaves))
 #  system.time(Get(traversal, function(node) Aggregate(node, "leafId", max)))
 
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 c(user = 1.418, system = 0.000, elapsed = 1.417)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  system.time(tree$Get(function(node) Aggregate(tree, "leafId", max, "maxLeafId"), traversal = "post-order"))
 
-## ---- echo = FALSE-------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 c(user = 0.69, system = 0.00, elapsed = 0.69)
 
